.yui3-skin-night .yui3-datatable .yui3-datatable-highlight-row td {
    background-color: #38383f;
}

.yui3-skin-night .yui3-datatable tr .yui3-datatable-highlight-col {
    background-color: #38383f;
}

.yui3-skin-night .yui3-datatable tr .yui3-datatable-highlight-cell {
    background-color: #38383f;
}
