.yui3-datatable tr td{-webkit-transition:background-color .05s ease-in;-moz-transition:background-color .05s ease-in;-o-transition:background-color .05s ease-in;transition:background-color .05s ease-in}.yui3-datatable .yui3-datatable-highlight-row td{-webkit-transition:background-color .1s ease-out;-moz-transition:background-color .1s ease-out;-o-transition:background-color .1s ease-out;transition:background-color .1s ease-out}.yui3-datatable tr .yui3-datatable-highlight-col{-webkit-transition:background-color .1s ease-out;-moz-transition:background-color .1s ease-out;-o-transition:background-color .1s ease-out;transition:background-color .1s ease-out}.yui3-datatable tr .yui3-datatable-highlight-cell{-webkit-transition:background-color .1s ease-out;-moz-transition:background-color .1s ease-out;-o-transition:background-color .1s ease-out;transition:background-color .1s ease-out}.yui3-skin-sam .yui3-datatable .yui3-datatable-highlight-row td{background-color:#fef2cd}.yui3-skin-sam .yui3-datatable tr .yui3-datatable-highlight-col{background-color:#fef2cd}.yui3-skin-sam .yui3-datatable tr .yui3-datatable-highlight-cell{background-color:#fef2cd}#yui3-css-stamp.skin-sam-datatable-highlight{display:none}
