.yui3-skin-sam .yui3-datatable .yui3-datatable-highlight-row td {
    background-color: #fef2cd;
}

.yui3-skin-sam .yui3-datatable tr .yui3-datatable-highlight-col {
    background-color: #fef2cd;
}

.yui3-skin-sam .yui3-datatable tr .yui3-datatable-highlight-cell {
    background-color: #fef2cd;
}
