.yui3-skin-sam .yui3-aclist-content {
    background: #fff;
    border: 1px solid #afafaf;
    -moz-box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.58);
    -webkit-box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.58);
    box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.58);
}

.yui3-skin-sam .yui3-aclist-item-hover {
    background: #bfdaff;
}

.yui3-skin-sam .yui3-aclist-item-active {
    background: #2647a0;
    color: #fff;
    outline: none;
}
