.yui3-datatable tr td{-webkit-transition:background-color .05s ease-in;-moz-transition:background-color .05s ease-in;-o-transition:background-color .05s ease-in;transition:background-color .05s ease-in}.yui3-datatable .yui3-datatable-highlight-row td{-webkit-transition:background-color .1s ease-out;-moz-transition:background-color .1s ease-out;-o-transition:background-color .1s ease-out;transition:background-color .1s ease-out}.yui3-datatable tr .yui3-datatable-highlight-col{-webkit-transition:background-color .1s ease-out;-moz-transition:background-color .1s ease-out;-o-transition:background-color .1s ease-out;transition:background-color .1s ease-out}.yui3-datatable tr .yui3-datatable-highlight-cell{-webkit-transition:background-color .1s ease-out;-moz-transition:background-color .1s ease-out;-o-transition:background-color .1s ease-out;transition:background-color .1s ease-out}.yui3-skin-night .yui3-datatable .yui3-datatable-highlight-row td{background-color:#38383f}.yui3-skin-night .yui3-datatable tr .yui3-datatable-highlight-col{background-color:#38383f}.yui3-skin-night .yui3-datatable tr .yui3-datatable-highlight-cell{background-color:#38383f}#yui3-css-stamp.skin-night-datatable-highlight{display:none}
