.yui3-aclist {
    position: absolute;
    z-index: 1;
}

.yui3-aclist-hidden { visibility: hidden; }

.yui3-aclist-aria {
    /* Hide from sighted users, show to screen readers. */
    left: -9999px;
    position: absolute;
}

.yui3-aclist-list {
    list-style: none;
    margin: 0;
    overflow: hidden;
    padding: 0;
}

.yui3-aclist-item {
    cursor: pointer;
    list-style: none;
    padding: 2px 5px;
}

.yui3-aclist-item-active { outline: #afafaf dotted thin; }
